OjaNP-package: Multivariate Methods Based on the Oja Median and Related Concepts
Description
The package provides functions for the Oja median, Oja signs and ranks and methods based upon them.Details
ll{
Package: OjaNP
Type: Package
Version: 0.9-7
Date: 2014-05-30
License: GPL (>= 2)
LazyLoad: yes
}
The package implements several algorithms to compute the Oja median as well as the Oja signs and ranks and methods based upon them.